from distutils.core import setup
setup(
  name = 'raspir',
  packages = ['raspir'],
  version = '1.1',
  description = 'A library to detect IR signals from receivers on Raspberry Pi',
  author = 'Pavlo Kochylo',
  author_email = 'kochylo.paolo@gmail.com',
  url = 'https://github.com/SyncroIT/Raspir',
  download_url = 'https://github.com/SyncroIT/Raspir/archive/1.1.tar.gz',
  keywords = ['ir', 'raspberry', 'infrared', 'decoder'],
  classifiers = [],
)
